@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.048'; # VERSION
+our $VERSION = '0.049'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -19,6 +19,7 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
+        [ 'dryrun'      => 'Do not commit any changes'        ],
         [ 'message|m=s' => 'Message to describe the change'   ],
         [ 'stack|s=s'   => 'Stack on which to pin the target' ],
     );
@@ -48,7 +49,7 @@ App::Pinto::Command::pin - force a package to stay in a stack
 
 =head1 VERSION
 
-version 0.048
+version 0.049
 
 =head1 SYNOPSIS
 
@@ -91,6 +92,12 @@ or ';') will be ignored.
 
 =over 4
 
+=item --dryrun
+
+Go through all the motions, but do not actually commit any changes to
+the repository.  Use this option to see how the command would
+potentially impact the stack.
+
 =item --message=TEXT
 
 =item -m TEXT
